@@ -137,7 +137,7 @@ def repr_value(value):
 
 
 def doc_setting(item):
-    fields = {}
+    fields = {'Path': f'``{repr(item)}``'}
     parents = list(item.parents())
     if parents and parents[0].meta is True:
         # too meta for us
@@ -168,7 +168,7 @@ def doc_setting(item):
 
 
 def doc_section(item):
-    fields = {}
+    fields = {'Path': f'``{repr(item)}``'}
     if item.meta is True:
         # too meta for us
         # this is section inside a meta section
